[Inicialmente, deve ser observado que a própria norma invocada pelo
requerente (artigo 1º, inciso VIII do decreto nº 2.151 de 12/02/2014)
**desde 2016 encontra-se revogada *pelo Decreto nº 420, publicado no dia
5 de fevereiro deste ano*** e, sendo o assunto disciplinado pelo art. 2o
da Instrução Normativa 12 de 2016 da SEMA*, de seguinte
teor:*]{dir="ltr"}

[:]{dir="ltr"}

*[Art. 2º Para fins desta Instrução Normativa, entende-se como limpeza
de áreas em imóveis rurais **as operações que envolvam
[roçada]{.underline}**, **retirada de plantas oportunistas e invasoras
em regeneração natural que tenha até 50 (cinquenta) indivíduos por
hectare com Diâmetro Altura do Peito-DAP com até 10 (dez) centímetros**,
**sem derrubada de árvores adultas**, desde que sejam
realizadas:]{dir="ltr"}*

*[I - em áreas consolidadas ou em áreas abertas após 22 de julho de
2008, autorizada ou regularizada pelos órgãos ambientais competentes,
e]{dir="ltr"}*

*[II- **[em áreas cujo tempo de pousio seja de até 5 (cinco) anos ou que
não ultrapasse a 3 (três) anos]{.underline}, quando se tratar de áreas
abandonadas**."]{dir="ltr"}*

[]{dir="ltr"}

[Ocorre que a materialidade de desmatamento ilegal na área foi concluída
por três órgãos diferentes (2a Companhia do Batalhão de Polícia Militar
de Proteção Ambiental, Ministério Público de Mato Grosso, pela
Promotoria de Justiça de Itiquira e Secretaria de Estado de Meio
Ambiente), sendo a primeira (**2a CIA do Batalhão de Polícia Militar de
Proteção Ambiental**) chegou a realizar visita "in loco", constando
situação que, juntamente com a prova decorrente de sensoriamento remoto
(imagens orbitais), demonstra ter havido supressão de vegetação nativa
em área de vegetação secundária cujas características (remoções de
árvores adultas) não permitem afirmar tratar-se de mera limpeza de
pastagem.]{dir="ltr"}

[De fato, os elementos informativos que comprovam o desmatamento ilegal
são vários:]{dir="ltr"}

1.  [A resolução dos Alertas da Plataforma *Global Forest Watch*,
    > utilizada pela Promotoria de Justiça de Itiquira (no âmbito do
    > Projeto Olhos da Mata, vencedor da XVI Edição do Prêmio Innovare -
    > categoria Ministério Público) destina-se a identificação de
    > desflorestamento de formação vegetal em densidade superior à mera
    > limpeza irregular de pastagem;]{dir="ltr"}

2.  [Boletim de Ocorrência N. **2019.166583, da 2a CIA do Batalhão de
    > Polícia Militar de Proteção Ambiental;**]{dir="ltr"}

3.  [Relatório Técnico **N. 080/2aCIA/BPMPA/2019,** da 2a CIA do
    > Batalhão de Polícia Militar de Proteção Ambiental, a partir de
    > diligência *in loco* e amostragem das árvores;]{dir="ltr"}

4.  [Termo de embargo **n. 118720**, da 2a CIA do Batalhão de Polícia
    > Militar de Proteção Ambiental;]{dir="ltr"}

5.  [**Relatório Técnico** ID **47717142 do Inquérito Civil
    > 000449-061/2019** do Ministério Público de Mato Grosso elaborado
    > pela Engenheira Ambiental Monalisa Janaya Castelo da Silva
    > Vasconcelos, auxiliar ministerial, confirmando o desmatamento
    > ilegal a partir de imagens de alta resolução;]{dir="ltr"}

6.  [**Autos de infração** N. **173419** e **173420 lavrados pela
    > SEMA**, **e respectivas dinâmicas de desmatamento**, sendo que, a
    > dinâmica de desmatamento elaborada pela SEMA revelou, ainda, a
    > ocorrência de um desmatamento ainda maior em 2018;]{dir="ltr"}

[Os alertas GLAD são gerados a partir de imagens do satélite ***Landsat
8***, cujo algoritmo de processamento desenvolvido identifica alterações
em áreas cobertas por árvores **acima de 5m de altura e com densidade de
cobertura do solo acima de 60%**. A validação dos alertas, feitas no
Peru, identificou a ocorrência de aproximadamente 13% de
falsos-positivos (emissão de alertas em áreas em que não houve perda de
cobertura arbórea) e 33% de falsos-negativos (não emissão de alertas em
áreas em que houve perda de cobertura arbórea), portanto, pode-se
considerar o método como conservador se avaliado pela sua acurácia. O
detalhamento da metodologia e dos resultados alcançados podem ser
consultados em Hansen *et al*. (2016)]{dir="ltr"}[^1][.]{dir="ltr"}

[Os mencionados alertas GLAD possuem a seguinte especificação
técnica:]{dir="ltr"}

[Logo, **a atividade praticada não se subsume à mera limpeza de
pastagens** que, no Estado de Mato Grosso, desde 2016 encontra definição
normativa no **art. 2º da Instrução Normativa n. 012, de 12 de fevereiro
de 2016**, acima transcrita.]{dir="ltr"}

[O volume das árvores em questão (nativas do Cerrado e, portanto, de
crescimento relativamente lento), bem como a densidade florestal
observada (superior a 60% de área com árvores com altura superior a 05
metros) é incompatível com a limpeza de pastagem, que se limita à
"roçada" (limpeza com a roçadeira ou instrumentos singelos) de pequenas
árvores e arbustos.]{dir="ltr"}

[A questão é bastante pacífica e encontra-se exaustivamente explicada
pela Secretaria de Estado de Meio Ambiente - SEMA, conforme se depreende
da notícia abaixo:]{dir="ltr"}

*[A partir desta semana, o produtor rural de Mato Grosso que realizar
limpeza de áreas em imóveis rurais deverá **protocolar a 'declaração de
limpeza' antes do início da atividade no endereço eletrônico da
Secretaria de Estado de Meio Ambiente (Sema).** (\...)]{dir="ltr"}*

*[Conforme a secretária Ana Luiza Peterlini (\...) "Cobrar essa
declaração demonstra que o Governo está levando a sério o compromisso
firmado na COP 21 de Paris de zerar o desmatamento ilegal até
2020"]{dir="ltr"}*

*[Ana Luiza pontua que **a Sema não está exigindo que o produtor peça
'autorização' do órgão ambiental para o procedimento**, mas apenas
tornou obrigatório que **declare antecipadamente quando for fazer a
limpeza, conforme já regulamentava o Decreto nº 2.151/2014, que foi
mantido pelo Decreto nº 420, publicado no dia 5 de fevereiro deste
ano**. A única novidade é ter revogado o inciso VIII do antigo decreto
que não cobrava a comunicação de limpeza à Sema. (\...)]{dir="ltr"}*

[*É importante esclarecer que a Instrução Normativa nº 12, publicada no
dia 15 de fevereiro, cobra a comunicação apenas daqueles produtores que
forem fazer a limpeza de áreas que envolvam roçada, retirada de plantas
oportunistas e invasoras em regeneração - que tenha até 50 centímetros
por hectare com diâmetro altura do peito (DAP) com até 10 centímetros -,
sem derrubada de árvores adultas. **Sobre o pousio, a legislação informa
que são consideradas apenas aquelas áreas em repouso por um período de
[até 5 anos, mas desde que não estejam abandonadas. Caso contrário, já
não se trata mais de 'limpeza de área' e sim de desmatamento e precisa
de autorização do órgão ambiental para a realização]{.underline}**.
"**[Se o produtor abriu a área na década de 1990, utilizou por um
período e depois abandonou por mais de 5 anos e a área já se regenerou
não se encaixa em limpeza, é desmatamento]{.underline}**", reforça a
secretária adjunta de Gestão Ambiental, Elaine Corsini.* (fonte:
[[http://www.mt.gov.br/-/2998633-sema-orienta-produtor-sobre-limpeza-de-areas-rurais]{.underline}](http://www.mt.gov.br/-/2998633-sema-orienta-produtor-sobre-limpeza-de-areas-rurais)
- g.n.)]{dir="ltr"}

[]{dir="ltr"}

[A notificação pelo Ministério Público ocorreu em 05/06/2019 (ID:
46485945/2).]{dir="ltr"}

[O laudo que apresenta declaração, em tese, falsa foi elaborado em
26/06/2019 e juntado nos autos em 27/06/2019 (ID: 46702954/2),
**aparentemente sem conhecimento (porque não mencionados) do Relatório
Técnico N. 080/2a.CIA/BPMA/2019**, previamente juntado aos autos, em
como os demais relatórios técnicos de teor diverso.]{dir="ltr"}

[Portanto, diante da prática, em tese, de afirmação falsa no bojo do
inquérito civil que instrui a presente, não restou ao membro do
Ministério Público outra alternativa senão requisitar à autoridade
policial, por meio da Delegacia Especializada do Meio Ambiente - DEMA
(Ofício n°: 178/2020/MPMT/PJ Itiquira) a instauração de inquérito
policial a fim de se averiguar a prática, em tese, do crime previsto no
art. 69-A da Lei dos Crimes Ambientais (Lei 9.605/98), inclusive a fim
de se aferir o elemento subjetivo do agente, conforme figuras típicas
aplicáveis ao caso:]{dir="ltr"}

*[Art. 69-A. Elaborar ou apresentar, no licenciamento, concessão
florestal **ou qualquer outro procedimento administrativo**, estudo,
**laudo ou relatório ambiental total ou parcialmente falso** ou
**enganoso, inclusive por omissão**:]{dir="ltr"}*

*[Pena - reclusão, de 3 (três) a 6 (seis) anos, e multa.]{dir="ltr"}*

*[§ 1o Se o crime é culposo:]{dir="ltr"}*

*[Pena - detenção, de 1 (um) a 3 (três) anos.]{dir="ltr"}*

[*§ 2o A pena é aumentada de 1/3 (um terço) a 2/3 (dois terços), se há
dano significativo ao meio ambiente, em decorrência do uso da informação
falsa, incompleta ou enganosa.*]{dir="ltr"}

[]{dir="ltr"}

[Quanto à alegação de a área ser consolidada, esta não prospera, já que
florestas desmatadas que se regeneram possuem proteção
legal.]{dir="ltr"}

[O marco temporal de 22/07/2008 serviu para anistiar crimes e infrações
administrativas ocorridas antes desta data -- e não como um direito
perpétuo de destruir a flora. A propósito, importante ressaltar que,
segundo a jurisprudência do Superior Tribunal de Justiça:]{dir="ltr"}

[***"(\...) [inexiste direito adquirido a poluir ou degradar o meio
ambiente. O tempo é incapaz de curar ilegalidades ambientais de natureza
permanente]{.underline}, pois parte dos sujeitos tutelados - as gerações
futuras - carece de voz e de representantes que falem ou se omitam em
seu nome."*** (AgInt no REsp 1283547/SC, Rel. Ministra REGINA HELENA
COSTA, PRIMEIRA TURMA, julgado em 23/10/2018, DJe
31/10/2018).]{dir="ltr"}

[Note-se que não só a vegetação primária ou prístina, mas também a
secundária (não só em estágio avançado como médio de regeneração) recebe
proteção do ordenamento jurídico Brasileiro, até mesmo na esfera
penal:]{dir="ltr"}

*[**Art. 38-A**. **Destruir ou danificar vegetação primária [ou
secundária, em estágio avançado ou médio de regeneração]{.underline}**,
do Bioma Mata Atlântica, ou utilizá-la com infringência das normas de
proteção:]{dir="ltr"}*

*[Pena - detenção, de 1 (um) a 3 (três) anos, ou multa, ou ambas as
penas cumulativamente.]{dir="ltr"}*

*[**Art. 48**. Impedir ou dificultar **a regeneração natural de
florestas e demais formas de vegetação**:]{dir="ltr"}*

*[Pena - detenção, de seis meses a um ano, e multa.]{dir="ltr"}*

[Além disso, uma das florestas mais conhecidas do Brasil, a Floresta da
Tijuca, no Rio de Janeiro, é, em grande parte, vegetação secundária,
cuja recuperação iniciou-se no século XIX, em razão de deslizamentos e,
principalmente, a crise hídrica no Rio de Janeiro levaram o imperador
Pedro II a desapropriar chácaras dos nobres que haviam se instalado nas
encostas da floresta e determinado o reflorestamento, o maior promovido
até então no país.]{dir="ltr"}

[]{dir="ltr"}

[^1]: [Hansen, M.C., A. Krylov, A. Tyukavina, P.V. Potapov, S.
    Turubanova, B. Zutta, S. Ifo, B. Margono, F. Stolle, & R. Moore.
    2016. Humid tropical forest disturbance alerts using Landsat
    data. *Environmental Research Letters*, 11 (3).]{dir="ltr"}
